@@ -1,14 +1,14 @@
-# Copyrights 2001-2015 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 use warnings;
 
 package Mail::Box;
 use vars '$VERSION';
-$VERSION = '2.118';
+$VERSION = '3.004';
 
 use base 'Mail::Reporter';
 
@@ -328,10 +328,11 @@ sub close(@)
                : croak "Unknown value to folder->close(write => $_).";
     }
 
+    my $locker = $self->locker;
     if($write && !$force && !$self->writable)
     {   $self->log(WARNING => "Changes not written to read-only folder $self.
 Suggestion: \$folder->close(write => 'NEVER')");
-        $self->locker->unlock;
+    	$locker->unlock if $locker;
         $self->{MB_messages} = [];    # Boom!
         return 0;
     }
@@ -342,7 +343,7 @@ Suggestion: \$folder->close(write => 'NEVER')");
                , save_deleted => $args{save_deleted} || 0
                );
 
-    $self->locker->unlock;
+    $locker->unlock if $locker;
     $self->{MB_messages} = [];                  # Boom!
     $rc;
 }
