@@ -1,18 +1,19 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker;
 use vars '$VERSION';
-$VERSION = '2.115';
+$VERSION = '3.004';
 
 use base 'Mail::Reporter';
 
 use Carp;
 use Scalar::Util 'weaken';
+use Devel::GlobalDestruction 'in_global_destruction';
 
 #-------------------------------------------
 
@@ -73,6 +74,19 @@ sub init($)
 #-------------------------------------------
 
 
+sub timeout(;$)
+{   my $self = shift;
+    @_ ? $self->{MBL_timeout} = shift : $self->{MBL_timeout};
+}
+
+sub expires(;$)
+{   my $self = shift;
+    @_ ? $self->{MBL_expires} = shift : $self->{MBL_expires};
+}
+
+#-------------------------------------------
+
+
 sub name {shift->notImplemented}
 
 sub lockMethod($$$$)
@@ -118,6 +132,8 @@ sub unlock() { shift->{MBL_has_lock} = 0 }
 
 sub DESTROY()
 {   my $self = shift;
+    return $self if in_global_destruction;
+
     $self->unlock if $self->hasLock;
     $self->SUPER::DESTROY;
     $self;
