@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::FcntlLock;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -39,7 +39,6 @@ sub _unlock($)
     my $fl = File::FcntlLock->new;
     $fl->l_type(F_UNLCK);
     $fl->lock($file, F_SETLK);
-    delete $self->{MBL_has_lock};
     $self;
 }
 
@@ -63,18 +62,20 @@ sub lock()
         return 0;
     }
 
-    my $end = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1 : $self->{MBL_timeout};
+    my $timeout = $self->timeout;
+    my $end     = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
 
     while(1)
     {   if($self->_try_lock($file))
-        {   $self->{MBL_has_lock}    = 1;
+        {   $self->SUPER::lock;
             $self->{MBLF_filehandle} = $file;
             return 1;
         }
 
         unless($!==EAGAIN)
-        {   $self->log(ERROR =>
-            "Will never get a FcntlLock lock on $filename for $self->{MBL_folder}: $!");
+        {   my $folder = $self->folder;
+            $self->log(ERROR =>
+                "Will never get a FcntlLock lock on $filename for $folder: $!");
             last;
         }
 
@@ -86,20 +87,24 @@ sub lock()
 }
 
 
+
 sub isLocked()
 {   my $self     = shift;
     my $filename = $self->filename;
 
     my $file     = IO::File->new($filename, "r");
     unless($file)
-    {   $self->log(ERROR =>
-               "Unable to check lock file $filename for $self->{MBL_folder}: $!");
+    {   my $folder = $self->folder;
+        $self->log(ERROR =>
+               "Unable to check lock file $filename for $folder: $!");
         return 0;
     }
 
     $self->_try_lock($file)==0 or return 0;
     $self->_unlock($file);
     $file->close;
+
+    $self->SUPER::unlock;
     1;
 }
 
@@ -109,6 +114,7 @@ sub unlock()
     $self->_unlock(delete $self->{MBLF_filehandle})
        if $self->hasLock;
 
+    $self->SUPER::unlock;
     $self;
 }
 
