@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::Flock;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -26,7 +26,6 @@ sub _try_lock($)
 sub _unlock($)
 {   my ($self, $file) = @_;
     flock $file, LOCK_UN;
-    delete $self->{MBL_has_lock};
     $self;
 }
 
@@ -53,13 +52,13 @@ sub lock()
         return 0;
     }
 
-    my $end = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1 : $self->{MBL_timeout};
+    my $timeout = $self->timeout;
+    my $end     = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
 
     while(1)
     {   if($self->_try_lock($file))
-        {   $self->{MBL_has_lock}    = 1;
-            $self->{MBLF_filehandle} = $file;
-            return 1;
+        {   $self->{MBLF_filehandle} = $file;
+            return $self->SUPER::lock;
         }
 
         if($! != EAGAIN)
@@ -82,8 +81,9 @@ sub isLocked()
 
     my $file     = IO::File->new($filename, $lockfile_access_mode);
     unless($file)
-    {   $self->log(ERROR =>
-            "Unable to check lock file $filename for $self->{MBL_folder}: $!");
+    {   my $folder = $self->folder;
+        $self->log(ERROR =>
+            "Unable to check lock file $filename for $folder: $!");
         return 0;
     }
 
@@ -91,6 +91,7 @@ sub isLocked()
     $self->_unlock($file);
     $file->close;
 
+    $self->SUPER::unlock;
     1;
 }
 
@@ -100,6 +101,7 @@ sub unlock()
     $self->_unlock(delete $self->{MBLF_filehandle})
         if $self->hasLock;
 
+    $self->SUPER::unlock;
     $self;
 }
 
