@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::Multi;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -20,8 +20,8 @@ sub init($)
 
     my @use
      = exists $args->{use} ? @{delete $args->{use}}
-     : $^O =~ m/mswin/i    ? qw/    POSIX Flock/
-     :                       qw/NFS POSIX Flock/;
+     : $^O eq 'MSWin32'    ? qw/Flock/
+     :                       qw/NFS FcntlLock Flock/;
 
     my (@lockers, @used);
 
@@ -73,10 +73,11 @@ sub _try_lock($)
 
 sub unlock()
 {   my $self = shift;
-    return $self unless $self->{MBL_has_lock};
+    $self->hasLock
+		or return $self;
 
     $_->unlock foreach $self->lockers;
-    delete $self->{MBL_has_lock};
+    $self->SUPER::unlock;
 
     $self;
 }
@@ -85,10 +86,11 @@ sub lock()
 {   my $self  = shift;
     return 1 if $self->hasLock;
 
-    my $end   = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1 : $self->{MBL_timeout};
+    my $timeout = $self->timeout;
+    my $end     = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
 
     while(1)
-    {   return $self->{MBL_has_lock} = 1
+    {   return $self->SUPER::lock
             if $self->_try_lock;
 
         last unless --$end;
@@ -100,7 +102,11 @@ sub lock()
 
 sub isLocked()
 {   my $self     = shift;
+
+    # Try get a lock
     $self->_try_lock($self->filename) or return 0;
+
+    # and release it immediately
     $self->unlock;
     1;
 }
