@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::Mutt;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -16,8 +16,8 @@ use POSIX      qw/sys_wait_h/;
 
 sub init($)
 {   my ($self, $args) = @_;
-
     $self->SUPER::init($args);
+
     $self->{MBLM_exe} = $args->{exe} || 'mutt_dotlock';
     $self;
 }
@@ -26,12 +26,14 @@ sub name()     {'MUTT'}
 sub lockfile() { shift->filename . '.lock' }
 
 
+
 sub exe() {shift->{MBLM_exe}}
 
 
+
 sub unlock()
 {   my $self = shift;
-    $self->{MBL_has_lock}
+    $self->hasLock
         or return $self;
 
     unless(system($self->exe, '-u', $self->filename))
@@ -39,11 +41,10 @@ sub unlock()
         $self->log(WARNING => "Couldn't remove mutt-unlock $folder: $!");
     }
 
-    delete $self->{MBL_has_lock};
+    $self->SUPER::unlock;
     $self;
 }
 
-#-------------------------------------------
 
 
 sub lock()
@@ -57,9 +58,9 @@ sub lock()
     my $filename = $self->filename;
     my $lockfn   = $self->lockfile;
 
-    my $end      = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1
-                 : $self->{MBL_timeout};
-    my $expire   = $self->{MBL_expires}/86400;  # in days for -A
+    my $timeout  = $self->timeout;
+    my $end      = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
+    my $expire   = $self->expires / 86400;  # in days for -A
     my $exe      = $self->exe;
 
     while(1)
@@ -71,7 +72,7 @@ sub lock()
             }
         }
         else
-        {   return $self->{MBL_has_lock} = 1;
+        {   return $self->SUPER::lock;
         }
 
         if(-e $lockfn && -A $lockfn > $expire)
@@ -94,7 +95,6 @@ sub lock()
     return 0;
 }
 
-#-------------------------------------------
 
 sub isLocked()
 {   my $self     = shift;
@@ -102,7 +102,5 @@ sub isLocked()
     WIFEXITED($?) && WEXITSTATUS($?)==3;
 }
 
-#-------------------------------------------
-
 1;
 
