@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::NFS;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -35,10 +35,7 @@ my $hostname = hostname;
 
 sub _tmpfilename()
 {   my $self = shift;
-    return $self->{MBL_tmp} if $self->{MBL_tmp};
-
-    my $folder = $self->{MBL_folder};
-    $self->{MBL_tmp} = $self->filename . $$;
+    $self->{MBLN_tmp} ||= $self->filename . $$;
 }
 
 sub _construct_tmpfile()
@@ -80,7 +77,7 @@ sub _unlock($$)
 
 sub lock()
 {   my $self     = shift;
-    my $folder   = $self->{MBL_folder};
+    my $folder   = $self->folder;
 
     if($self->hasLock)
     {   $self->log(WARNING => "Folder $folder already locked over nfs");
@@ -89,9 +86,9 @@ sub lock()
 
     my $lockfile = $self->filename;
     my $tmpfile  = $self->_construct_tmpfile or return;
-    my $end      = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1
-                 : $self->{MBL_timeout};
-    my $expires  = $self->{MBL_expires}/86400;  # in days for -A
+    my $timeout  = $self->timeout;
+    my $end      = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
+    my $expires  = $self->expires / 86400;  # in days for -A
 
     if(-e $lockfile && -A $lockfile > $expires)
     {   if(unlink $lockfile)
@@ -101,10 +98,8 @@ sub lock()
     }
 
     while(1)
-    {   if($self->_try_lock($tmpfile, $lockfile))
-        {   $self->{MBL_has_lock} = 1;
-            return 1;
-        }
+    {   return $self->SUPER::lock
+			if $self->_try_lock($tmpfile, $lockfile);
 
         last unless --$end;
         sleep 1;
@@ -124,6 +119,8 @@ sub isLocked()
 
     close $fh;
     $self->_unlock($tmpfile, $lockfile);
+    $self->SUPER::unlock;
+
     1;
 }
 
@@ -134,7 +131,7 @@ sub unlock($)
     return $self unless $self->hasLock;
 
     $self->_unlock($self->_tmpfilename, $self->filename);
-    delete $self->{MBL_has_lock};
+    $self->SUPER::unlock;
     $self;
 }
 
