@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Locker::POSIX;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Locker';
 
@@ -15,6 +15,12 @@ use Fcntl;
 use IO::File;
 use Errno   qw/EAGAIN/;
 
+# fcntl() should not be used without XS: the below is sensitive
+# for changes in the structure.  However, at the moment it seems
+# there are only two options: either SysV-style or BSD-style
+
+my $pack_pattern = $^O =~ /bsd|darwin/i ? '@20 s @256' : 's @256';
+
 
 sub init($)
 {   my ($self, $args) = @_;
@@ -26,20 +32,20 @@ sub name() {'POSIX'}
 
 sub _try_lock($)
 {   my ($self, $file) = @_;
-    my $p = pack 's @256', F_WRLCK;
+    my $p = pack $pack_pattern, F_WRLCK;
     $? = fcntl($file, F_SETLK, $p) || ($!+0);
     $?==0;
 }
 
 sub _unlock($)
 {   my ($self, $file) = @_;
-    my $p = pack 's @256', F_UNLCK;
+    my $p = pack $pack_pattern, F_UNLCK;
     fcntl $file, F_SETLK, $p;
-    delete $self->{MBL_has_lock};
     $self;
 }
 
 
+
 sub lock()
 {   my $self   = shift;
 
@@ -50,27 +56,27 @@ sub lock()
     }
 
     my $filename = $self->filename;
+    my $folder   = $self->folder;
 
-    my $file   = IO::File->new($filename, 'r+');
+    my $file     = IO::File->new($filename, 'r+');
     unless(defined $file)
-    {   my $folder = $self->folder;
-        $self->log(ERROR =>
+    {   $self->log(ERROR =>
            "Unable to open POSIX lock file $filename for $folder: $!");
         return 0;
     }
 
-    my $end = $self->{MBL_timeout} eq 'NOTIMEOUT' ? -1 : $self->{MBL_timeout};
+    my $timeout  = $self->timeout;
+    my $end      = $timeout eq 'NOTIMEOUT' ? -1 : $timeout;
 
     while(1)
     {   if($self->_try_lock($file))
-        {   $self->{MBL_has_lock}    = 1;
-            $self->{MBLF_filehandle} = $file;
-            return 1;
+        {   $self->{MBLF_filehandle} = $file;
+            return $self->SUPER::lock;
         }
 
         unless($!==EAGAIN)
         {   $self->log(ERROR =>
-            "Will never get a POSIX lock on $filename for $self->{MBL_folder}: $!");
+               "Will never get a POSIX lock on $filename for $folder: $!");
             last;
         }
 
@@ -88,14 +94,16 @@ sub isLocked()
 
     my $file     = IO::File->new($filename, "r");
     unless($file)
-    {   $self->log(ERROR =>
-               "Unable to check lock file $filename for $self->{MBL_folder}: $!");
+    {   my $folder = $self->folder;
+        $self->log(ERROR => "Unable to check lock file $filename for $folder: $!");
         return 0;
     }
 
     $self->_try_lock($file)==0 or return 0;
     $self->_unlock($file);
     $file->close;
+
+    $self->SUPER::unlock;
     1;
 }
 
@@ -105,6 +113,7 @@ sub unlock()
     $self->_unlock(delete $self->{MBLF_filehandle})
        if $self->hasLock;
 
+    $self->SUPER::unlock;
     $self;
 }
 
