@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use strict;
 use warnings;
 
 package Mail::Box::Manager;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.004';
 
 use base 'Mail::Reporter';
 
@@ -159,19 +159,19 @@ sub open(@)
     {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
         my $srv  = $args{server_name} ||= 'localhost';
         my $port = $args{server_port} ||= 110;
-        $args{folder} = $name = "pop3://$un\@$srv:$port";
+        $args{folderdir} = $name = "pop3://$un\@$srv:$port";
     }
     elsif($type eq 'pop3s')
     {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
         my $srv  = $args{server_name} ||= 'localhost';
         my $port = $args{server_port} ||= 995;
-        $args{folder} = $name = "pop3s://$un\@$srv:$port";
+        $args{folderdir} = $name = "pop3s://$un\@$srv:$port";
     }
     elsif($type eq 'imap4')
     {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
         my $srv  = $args{server_name} ||= 'localhost';
         my $port = $args{server_port} ||= 143;
-        $args{folder} = $name = "imap4://$un\@$srv:$port";
+        $args{folderdir} = $name = "imap4://$un\@$srv:$port";
     }
 
     unless(defined $name && length $name)
