@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Box::Message::Destructed;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '3.004';
 
 use base 'Mail::Box::Message';
 
@@ -20,12 +20,8 @@ sub new(@)
     undef;
 }
  
-#-------------------------------------------
-
 sub isDummy()    { 1 }
 
-#-------------------------------------------
-
 
 sub head(;$)
 {    my $self = shift;
@@ -35,8 +31,6 @@ sub head(;$)
      undef;
 }
 
-#-------------------------------------------
-
 
 sub body(;$)
 {    my $self = shift;
@@ -46,8 +40,6 @@ sub body(;$)
      undef;
 }
 
-#-------------------------------------------
-
 
 sub coerce($)
 {  my ($class, $message) = @_;
@@ -64,8 +56,6 @@ sub coerce($)
    bless $message, $class;
 }
 
-#-------------------------------------------
-
 sub modified(;$)
 {  my $self = shift;
 
@@ -77,8 +67,6 @@ sub modified(;$)
 
 sub isModified() { 0 }
 
-#-------------------------------------------
-
 
 sub label($;@)
 {  my $self = shift;
@@ -102,8 +90,6 @@ sub label($;@)
    1;
 }
 
-#-------------------------------------------
-
-sub labels() { wantarray ? ('deleted') : { deleted => 1 } }
+sub labels() { wantarray ? ('deleted') : +{deleted => 1} }
 
 1;
