@@ -1,13 +1,13 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use strict;
 
 package Mail::Message::Head::Subset;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '3.004';
 
 use base 'Mail::Message::Head';
 
@@ -16,22 +16,16 @@ use Object::Realize::Later
     realize        => 'load',
     believe_caller => 1;
 
-use Date::Parse;
+use Date::Parse qw(str2time);
 
 
 sub count($)
 {   my ($self, $name) = @_;
-
-    my @values = $self->get($name);
-
-    return $self->load->count($name)
-       unless @values;
-
+    my @values = $self->get($name)
+        or return $self->load->count($name);
     scalar @values;
 }
 
-#-------------------------------------------
-
 
 sub get($;$)
 {   my $self = shift;
@@ -51,7 +45,6 @@ sub get($;$)
 
 #-------------------------------------------
 
-
 sub guessBodySize()
 {   my $self = shift;
 
@@ -89,9 +82,6 @@ sub guessTimestamp()
 
 #-------------------------------------------
 
-
 sub load() { $_[0] = $_[0]->message->loadHead }
 
-#------------------------------------------
-
 1;
